@@ -17,19 +17,11 @@ logger = logging.getLogger(__name__)
 
 class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
 
-    '''
-        ``tmux(1)`` pane.
+    """:term:`tmux(1)` :ref:`pane`.
 
-        pane holds a psuedoterm and linked to tmux windows.
+    :param window: :class:`Window`
 
-        Retrieve a tmux pane from server. Returns :class:`Pane`.
-
-        Iterates ``$ tmux list-panes``, ``-F`` for return formatting.
-
-        :param session: :class:`Session` object.
-        :param window: :class:`Window` object.
-
-    '''
+    """
 
     def __init__(self, window=None, **kwargs):
         if not window:
@@ -43,7 +35,6 @@ class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
         self._pane_id = kwargs['pane_id']
 
         self.server._update_panes()
-        # self.update(**kwargs)
 
     @property
     def _TMUX(self, *args):
@@ -64,13 +55,17 @@ class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
 
         return list(filter(by, self.server._panes))[0]
 
-    # def __getitem__(self, key):
-    #    return
+    def tmux(self, cmd, *args, **kwargs):
+        """Send command to tmux with :attr:`pane_id` as ``target-pane``.
 
-    def tmux(self, *args, **kwargs):
-        # if '-t' not in kwargs:
-        #    kwargs['-t'] = self.get['session_id']
-        return self.server.tmux(*args, **kwargs)
+        Specifying ``('-t', 'custom-target')`` or ``('-tcustom_target')`` in
+        ``args`` will override using the object's ``pane_id`` as target.
+
+        """
+        if not len([arg for arg in args if '-t' in arg]):
+            args = ('-t', self.get('pane_id')) + args
+
+        return self.server.tmux(cmd, *args, **kwargs)
 
     def send_keys(self, cmd, enter=True):
         '''
@@ -78,11 +73,36 @@ class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
 
             :param enter: bool. send enter after sending the key.
         '''
-        self.tmux('send-keys', '-t%s' % self.target, cmd)
+        self.tmux('send-keys', cmd)
 
         if enter:
             self.enter()
 
+    def clear(self):
+        """Clear pane."""
+        self.send_keys('reset')
+
+    def reset(self):
+        """Reset and clear pane history. """
+
+        self.tmux('send-keys', '-R \; clear-history')
+
+    def set_width(self, width):
+        """Set width of pane.
+
+            :param width: pane width, in cells.
+            :type width: int
+        """
+        self.resize_pane(width=width)
+
+    def set_height(self, height):
+        """Set height of pane.
+
+            :param height: pane height, in cells.
+            :type height: int
+        """
+        self.resize_pane(height=height)
+
     def resize_pane(self, *args, **kwargs):
         '''
             ``$ tmux resize-pane``
@@ -95,15 +115,12 @@ class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
         # if isinstance(target_pane, basestring) and not ':' not in target_pane or isinstance(target_pane, int):
         #    target_pane = "%s.%s" % (self.target, target_pane)
 
-        # logger.error('resize-pane', '-t%s' % self.target)
         if 'height' in kwargs:
-            proc = self.tmux('resize-pane', '-t%s' %
-                             self.target, '-y%s' % int(kwargs['height']))
+            proc = self.tmux('resize-pane', '-y%s' % int(kwargs['height']))
         elif 'width' in kwargs:
-            proc = self.tmux('resize-pane', '-t%s' %
-                             self.target, '-x%s' % int(kwargs['width']))
+            proc = self.tmux('resize-pane', '-x%s' % int(kwargs['width']))
         else:
-            proc = self.tmux('resize-pane', '-t%s' % self.target, args[0])
+            proc = self.tmux('resize-pane', args[0])
 
         if proc.stderr:
             raise Exception(proc.stderr)
@@ -115,13 +132,7 @@ class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
         '''
             ``$ tmux send-keys`` send Enter to the pane.
         '''
-        self.tmux('send-keys', '-t%s' % self.target, 'Enter')
-
-    @property
-    def target(self):
-        # return "%s:%s.%s" % (self.session.get('session_id'),
-        # self.get('window_id'), self.get('pane_index'))
-        return self.get('pane_id')
+        self.tmux('send-keys', 'Enter')
 
     def __repr__(self):
         return "%s(%s %s)" % (self.__class__.__name__, self.get('pane_id'), self.window)
